@@ -1,27 +1,27 @@
-DR_data <- function(Y,                                  
-                    trafo = sqrt(.Machine$double.eps),  
-                    base  = 1,                          
-                    norm_tol = sqrt(.Machine$double.eps)
+DR_data <- function(Y,                                   # response (compositional variable)
+                    trafo = sqrt(.Machine$double.eps),   # transform (compress) the data?
+                    base  = 1,                           # base variable for the reparametrized (alternative) model
+                    norm_tol = sqrt(.Machine$double.eps) # tolerance for normalization [0, ?]
                    ){
 
 
+# initialization
+  force.norm <- FALSE   # was normalization forced?
+  state.tran <- FALSE   # was Y transformed?
+  force.tran <- FALSE   # was transformation forced?
 
-  force.norm <- FALSE  
-  state.tran <- FALSE  
-  force.tran <- FALSE  
-
-
+# set all rows containing NAs to NA
   if(any(is.na(Y))){ Y[which(rowSums(is.na(Y)) > 0),] <- NA }
 
-
+# check for negative values in Y
   if(any(na.delete(Y) < 0)) stop('"Y" contains values < 0.')
 
-
+# save the original data for reference
   Y.original <- Y
 
 
 
-
+### CONVENIENTLY HANDLE BETA-DISTRIBUTED VARIABLES
   if((!is.matrix(Y) && !is.data.frame(Y)) || ifelse(is.null(ncol(Y)), FALSE, ncol(Y) == 1L)){
     if(any((na.delete(Y) < 0) || (na.delete(Y) > 1))){
       stop('only one variable supplied with values outside [0, 1].\nbeta distribution cannot safely be assumed.\nprepare your data first.')
@@ -29,8 +29,8 @@ DR_data <- function(Y,
     Y <- cbind(1.0-Y, Y)
 
     .name <- deparse(match.call()$Y)
-    .name <- gsub(".*\\$", "", .name)  
-    .name <- gsub("\\[.*", "", .name)  
+    .name <- gsub(".*\\$", "", .name)   # eliminate references to the object the variable comes from
+    .name <- gsub("\\[.*", "", .name)   # eliminate indices
     if(length(.name) == 0L) .name <- "Y"
     colnames(Y) <- c(paste("1 -", .name), .name)
 
@@ -39,7 +39,7 @@ DR_data <- function(Y,
 
 
 
-
+### CHECKS
   if(!is.matrix(Y) && !is.data.frame(Y)) stop('"Y" must be either a matrix or a data.frame.')
   if(ncol(Y) <= 1) stop('"Y" must at least have two columns.')
   if((base < 1) || (base > ncol(Y))) stop('"base" must be in the range of variables.')
@@ -51,7 +51,7 @@ DR_data <- function(Y,
 
 
 
-
+### NORMALIZATION - forced only if rowSums != 1 w/tolerance = norm_tol
   row.sums <- rowSums(Y)
 
   if( !isTRUE(all.equal( na.delete(row.sums), rep(1.0, length(na.delete(row.sums))), tolerance = norm_tol, check.attributes = FALSE)) ){
@@ -61,7 +61,7 @@ DR_data <- function(Y,
 
 
 
-
+### TRANSFORMATION
   if( (is.logical(trafo) && trafo) ||
       (is.numeric(trafo) && any(na.delete(Y) < trafo, na.rm=TRUE) || any(na.delete(Y) > (1-trafo), na.rm=TRUE)) ){
     n.obs <- length(na.delete(row.sums))
@@ -80,7 +80,7 @@ DR_data <- function(Y,
 
 
 
-
+### OBJECT DEFINITION
   res <- structure(
     as.matrix(Y),
     "Y.original"  = as.data.frame(Y.original),
@@ -96,7 +96,7 @@ DR_data <- function(Y,
 
 
 
-
+### warnings
   if(force.norm && force.tran){
     warning("not all rows sum up to 1 => normalization forced\n  some entries are 0 or 1 => transformation forced", immediate.=TRUE)
   } else if(force.norm){
